@@ -39,7 +39,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddSmsSign", params)
+            headers = request.headers
+            body = self.call("AddSmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddSmsSignResponse()
@@ -70,7 +71,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddSmsTemplate", params)
+            headers = request.headers
+            body = self.call("AddSmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddSmsTemplateResponse()
@@ -100,7 +102,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CallbackStatusStatistics", params)
+            headers = request.headers
+            body = self.call("CallbackStatusStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CallbackStatusStatisticsResponse()
@@ -130,7 +133,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSmsSign", params)
+            headers = request.headers
+            body = self.call("DeleteSmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSmsSignResponse()
@@ -160,7 +164,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSmsTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteSmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSmsTemplateResponse()
@@ -189,7 +194,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePhoneNumberInfo", params)
+            headers = request.headers
+            body = self.call("DescribePhoneNumberInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePhoneNumberInfoResponse()
@@ -219,7 +225,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSmsSignList", params)
+            headers = request.headers
+            body = self.call("DescribeSmsSignList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSmsSignListResponse()
@@ -249,7 +256,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSmsTemplateList", params)
+            headers = request.headers
+            body = self.call("DescribeSmsTemplateList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSmsTemplateListResponse()
@@ -281,7 +289,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySmsSign", params)
+            headers = request.headers
+            body = self.call("ModifySmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySmsSignResponse()
@@ -313,7 +322,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySmsTemplate", params)
+            headers = request.headers
+            body = self.call("ModifySmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySmsTemplateResponse()
@@ -334,6 +344,7 @@ class SmsClient(AbstractClient):
     def PullSmsReplyStatus(self, request):
         """拉取短信回复状态。
         目前也支持 [配置回复回调](https://cloud.tencent.com/document/product/382/42907) 的方式来获取上行回复。
+        >- 注：此接口需要联系 [腾讯云短信小助手](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81) 开通。
         >- 注：由于云 **API3.0 安全性**有所提升，所以**接口鉴权**较为复杂，建议使用 SDK 来使用云短信服务。
         >- 您可以在 [API 3.0 Explorer](https://console.cloud.tencent.com/api/explorer?Product=sms&Version=2021-01-11&Action=SendSms) 中直接运行该接口，可以先免去签名计算步骤。运行成功后，API Explorer可以**自动生成**SDK代码示例。
 
@@ -344,7 +355,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsReplyStatus", params)
+            headers = request.headers
+            body = self.call("PullSmsReplyStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsReplyStatusResponse()
@@ -375,7 +387,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsReplyStatusByPhoneNumber", params)
+            headers = request.headers
+            body = self.call("PullSmsReplyStatusByPhoneNumber", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsReplyStatusByPhoneNumberResponse()
@@ -407,7 +420,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsSendStatus", params)
+            headers = request.headers
+            body = self.call("PullSmsSendStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsSendStatusResponse()
@@ -438,7 +452,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsSendStatusByPhoneNumber", params)
+            headers = request.headers
+            body = self.call("PullSmsSendStatusByPhoneNumber", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsSendStatusByPhoneNumberResponse()
@@ -456,10 +471,41 @@ class SmsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ReportConversion(self, request):
+        """短信转化率上报。将已接收到短信的流水号上报到腾讯云短信服务。
+        >- 注：当前接口以白名单方式对外开放，如有需要请联系 [腾讯云短信小助手](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81) 开通。
+
+        :param request: Request instance for ReportConversion.
+        :type request: :class:`tencentcloud.sms.v20210111.models.ReportConversionRequest`
+        :rtype: :class:`tencentcloud.sms.v20210111.models.ReportConversionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ReportConversion", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ReportConversionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SendSms(self, request):
         """短信发送接口，用于给用户发短信验证码、通知类短信或营销短信。
-        >- 注：由于云 **API3.0 安全性**有所提升，所以**接口鉴权**较为复杂，建议使用 SDK 来使用云短信服务。
-        >- 您可以在 [API 3.0 Explorer](https://console.cloud.tencent.com/api/explorer?Product=sms&Version=2021-01-11&Action=SendSms) 中直接运行该接口，可以先免去签名计算步骤。运行成功后，API Explorer可以**自动生成**SDK代码示例。
+        >- 注：由于云 **API3.0 安全性**有所提升，所以**接口鉴权**较为复杂，建议使用 [SDK](https://cloud.tencent.com/document/product/382/43193) 来使用云短信服务。
+        >- 注：您可以在 [API 3.0 Explorer](https://console.cloud.tencent.com/api/explorer?Product=sms&Version=2021-01-11&Action=SendSms) 中直接运行该接口，可以先免去签名计算步骤。运行成功后，API Explorer可以**自动生成**SDK代码示例。
+        >- 注：当前接口属于 2021-01-11 版本，如果您仍在使用 [2019-07-11 版本](https://cloud.tencent.com/document/product/382/38778)，建议您使用当前最新版本的接口，版本差异可参考[版本描述](https://cloud.tencent.com/document/product/382/63195#.E7.89.88.E6.9C.AC.E6.8F.8F.E8.BF.B0)。
 
         :param request: Request instance for SendSms.
         :type request: :class:`tencentcloud.sms.v20210111.models.SendSmsRequest`
@@ -468,7 +514,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendSms", params)
+            headers = request.headers
+            body = self.call("SendSms", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendSmsResponse()
@@ -498,7 +545,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendStatusStatistics", params)
+            headers = request.headers
+            body = self.call("SendStatusStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendStatusStatisticsResponse()
@@ -528,7 +576,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SmsPackagesStatistics", params)
+            headers = request.headers
+            body = self.call("SmsPackagesStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SmsPackagesStatisticsResponse()
