@@ -77,6 +77,9 @@ FAILEDOPERATION_FILETOOLARGE = 'FailedOperation.FileTooLarge'
 # 文件尺寸太小，请上传清晰图片。
 FAILEDOPERATION_FILETOOSMALL = 'FailedOperation.FileTooSmall'
 
+# 公司管理人状态错误。
+FAILEDOPERATION_ILLEGALMANAGERSTATUS = 'FailedOperation.IllegalManagerStatus'
+
 # 证书来源错误。
 FAILEDOPERATION_INVALIDCERTIFICATESOURCE = 'FailedOperation.InvalidCertificateSource'
 
@@ -131,6 +134,9 @@ FAILEDOPERATION_ROLENOTFOUNDAUTHORIZATION = 'FailedOperation.RoleNotFoundAuthori
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# 后端服务响应为空。
+INTERNALERROR_BACKENDRESPONSEEMPTY = 'InternalError.BackendResponseEmpty'
+
 # 后端服务响应错误。
 INTERNALERROR_BACKENDRESPONSEERROR = 'InternalError.BackendResponseError'
 
@@ -140,12 +146,18 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 查询的证书ID不能超过50个。
 INVALIDPARAMETER_CERTIFICATEIDNUMBERLIMIT = 'InvalidParameter.CertificateIdNumberLimit'
 
+# 证书数量超出限制。
+INVALIDPARAMETER_CERTIFICATESNUMBEREXCEEDED = 'InvalidParameter.CertificatesNumberExceeded'
+
 # 包含无效的证书ID。
 INVALIDPARAMETER_CONTAINSINVALIDCERTIFICATEID = 'InvalidParameter.ContainsInvalidCertificateId'
 
 # 权益点ID列表无效。
 INVALIDPARAMETER_PACKAGEIDSINVALID = 'InvalidParameter.PackageIdsInvalid'
 
+# 参数有误。
+INVALIDPARAMETER_WITHDETAILREASON = 'InvalidParameter.WithDetailReason'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
