@@ -71,18 +71,102 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 操作频繁，请稍后重试。
 INVALIDPARAMETER_ACTIONINPROGRESS = 'InvalidParameter.ActionInProgress'
 
+# HTTPS证书链错误。
+INVALIDPARAMETER_CERTCHAINERROR = 'InvalidParameter.CertChainError'
+
+# 证书错误。
+INVALIDPARAMETER_CERTCHECKERROR = 'InvalidParameter.CertCheckError'
+
+# 证书错误。
+INVALIDPARAMETER_CERTCOMPLETEERROR = 'InvalidParameter.CertCompleteError'
+
+# 证书错误。
+INVALIDPARAMETER_CERTFORMATERROR = 'InvalidParameter.CertFormatError'
+
+# HTTPS证书已过期。
+INVALIDPARAMETER_CERTISEXPIRED = 'InvalidParameter.CertIsExpired'
+
+# 证书错误。
+INVALIDPARAMETER_CERTNOCN = 'InvalidParameter.CertNoCn'
+
+# 无效的HTTPS证书。
+INVALIDPARAMETER_CERTNOINFO = 'InvalidParameter.CertNoInfo'
+
 # HTTPS证书和域名不匹配。
 INVALIDPARAMETER_CERTNOTMATCHDOMAIN = 'InvalidParameter.CertNotMatchDomain'
 
+# HTTPS证书和密钥不匹配。
+INVALIDPARAMETER_CERTNOTMATCHKEY = 'InvalidParameter.CertNotMatchKey'
+
+# 证书错误。
+INVALIDPARAMETER_CERTNOTPEM = 'InvalidParameter.CertNotPem'
+
+# 内部错误。
+INVALIDPARAMETER_CERTSYSTEMERROR = 'InvalidParameter.CertSystemError'
+
+# HTTPS证书即将过期。
+INVALIDPARAMETER_CERTTOEXPIRE = 'InvalidParameter.CertToExpire'
+
+# 证书错误。
+INVALIDPARAMETER_CERTTOOSHORTKEYSIZE = 'InvalidParameter.CertTooShortKeySize'
+
+# 证书错误。
+INVALIDPARAMETER_CERTUNSUPPORTEDTYPE = 'InvalidParameter.CertUnsupportedType'
+
 # 域名不存在或不属于该账号。
 INVALIDPARAMETER_DOMAINNOTFOUND = 'InvalidParameter.DomainNotFound'
 
+# 当前域名已开启流量调度功能。
+INVALIDPARAMETER_DOMAINONTRAFFICSCHEDULING = 'InvalidParameter.DomainOnTrafficScheduling'
+
+# 非法操作。
+INVALIDPARAMETER_ERRINVALIDACTION = 'InvalidParameter.ErrInvalidAction'
+
+# 非法操作-非法参数。
+INVALIDPARAMETER_ERRINVALIDACTIONPARAM = 'InvalidParameter.ErrInvalidActionParam'
+
+# 非法操作-非法参数-参数名重复。
+INVALIDPARAMETER_ERRINVALIDACTIONPARAMDUPLICATENAME = 'InvalidParameter.ErrInvalidActionParamDuplicateName'
+
+# 非法操作-非法参数-参数值数量超出限制。
+INVALIDPARAMETER_ERRINVALIDACTIONPARAMTOOMANYVALUES = 'InvalidParameter.ErrInvalidActionParamTooManyValues'
+
+# 非法操作-非法类型。
+INVALIDPARAMETER_ERRINVALIDACTIONTYPE = 'InvalidParameter.ErrInvalidActionType'
+
+# 非法条件-非法忽略大小写。
+INVALIDPARAMETER_ERRINVALIDCONDITIONIGNORECASE = 'InvalidParameter.ErrInvalidConditionIgnoreCase'
+
+# 非法条件-非法参数名称-匹配类型不支持参数名称。
+INVALIDPARAMETER_ERRINVALIDCONDITIONNAMETARGETNOTSUPPORTNAME = 'InvalidParameter.ErrInvalidConditionNameTargetNotSupportName'
+
+# 非法条件-非法参数值-无效的参数值。
+INVALIDPARAMETER_ERRINVALIDCONDITIONVALUEBADVALUE = 'InvalidParameter.ErrInvalidConditionValueBadValue'
+
+# 非法条件-非法参数值-无效的参数值-文件名不应包含文件后缀。
+INVALIDPARAMETER_ERRINVALIDCONDITIONVALUEBADVALUECONTAINFILENAMEEXTENSION = 'InvalidParameter.ErrInvalidConditionValueBadValueContainFileNameExtension'
+
+# 非法条件-非法参数值-参数值长度超出限制。
+INVALIDPARAMETER_ERRINVALIDCONDITIONVALUETOOLONGVALUE = 'InvalidParameter.ErrInvalidConditionValueTooLongValue'
+
+# 非法条件-非法参数值-参数值数量为0。
+INVALIDPARAMETER_ERRINVALIDCONDITIONVALUEZEROLENGTH = 'InvalidParameter.ErrInvalidConditionValueZeroLength'
+
 # 域名不存在。
 INVALIDPARAMETER_HOSTNOTFOUND = 'InvalidParameter.HostNotFound'
 
+# 无效的token鉴权。
+INVALIDPARAMETER_INVALIDAUTHENTICATION = 'InvalidParameter.InvalidAuthentication'
+
 # 无效的token鉴权参数。
 INVALIDPARAMETER_INVALIDAUTHENTICATIONTYPESIGNPARAM = 'InvalidParameter.InvalidAuthenticationTypeSignParam'
 
+# 无效的缓存键。
+INVALIDPARAMETER_INVALIDCACHEKEY = 'InvalidParameter.InvalidCacheKey'
+
+# 无效的查询字符串。
+INVALIDPARAMETER_INVALIDCACHEKEYQUERYSTRINGVALUE = 'InvalidParameter.InvalidCacheKeyQueryStringValue'
+
 # 无效的节点缓存。
 INVALIDPARAMETER_INVALIDCACHEONLYONSWITCH = 'InvalidParameter.InvalidCacheOnlyOnSwitch'
 
@@ -98,6 +182,15 @@ INVALIDPARAMETER_INVALIDDYNAMICROUTINE = 'InvalidParameter.InvalidDynamicRoutine
 # 无效的自定义错误页面。
 INVALIDPARAMETER_INVALIDERRORPAGEREDIRECTURL = 'InvalidParameter.InvalidErrorPageRedirectUrl'
 
+# 无效的HTTPS HSTS。
+INVALIDPARAMETER_INVALIDHTTPSHSTSMAXAGE = 'InvalidParameter.InvalidHttpsHstsMaxAge'
+
+# 无效的HTTPS TLS版本。
+INVALIDPARAMETER_INVALIDHTTPSTLSVERSION = 'InvalidParameter.InvalidHttpsTlsVersion'
+
+# 无效的Ipv6开关配置。
+INVALIDPARAMETER_INVALIDIPV6SWITCH = 'InvalidParameter.InvalidIpv6Switch'
+
 # 无效的源站。
 INVALIDPARAMETER_INVALIDORIGIN = 'InvalidParameter.InvalidOrigin'
 
@@ -107,12 +200,21 @@ INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'
 # 套餐包不支持最大上传大小。
 INVALIDPARAMETER_INVALIDPOSTMAXSIZEBILLING = 'InvalidParameter.InvalidPostMaxSizeBilling'
 
+# 无效的最大上传大小。
+INVALIDPARAMETER_INVALIDPOSTSIZEVALUE = 'InvalidParameter.InvalidPostSizeValue'
+
 # 无效的请求头header。
 INVALIDPARAMETER_INVALIDREQUESTHEADERNAME = 'InvalidParameter.InvalidRequestHeaderName'
 
 # 无套餐包。
 INVALIDPARAMETER_INVALIDRESOURCEIDBILLING = 'InvalidParameter.InvalidResourceIdBilling'
 
+# 无效的响应头header。
+INVALIDPARAMETER_INVALIDRESPONSEHEADERNAME = 'InvalidParameter.InvalidResponseHeaderName'
+
+# 无效的规则引擎配置。
+INVALIDPARAMETER_INVALIDRULEENGINE = 'InvalidParameter.InvalidRuleEngine'
+
 # 无效的规则引擎操作。
 INVALIDPARAMETER_INVALIDRULEENGINEACTION = 'InvalidParameter.InvalidRuleEngineAction'
 
@@ -128,6 +230,9 @@ INVALIDPARAMETER_INVALIDRULEENGINETARGETSEXTENSION = 'InvalidParameter.InvalidRu
 # 无效的规则引擎URL条件。
 INVALIDPARAMETER_INVALIDRULEENGINETARGETSURL = 'InvalidParameter.InvalidRuleEngineTargetsUrl'
 
+# 无效的回源Host。
+INVALIDPARAMETER_INVALIDSERVERNAME = 'InvalidParameter.InvalidServerName'
+
 # URL重写的目标HOST无效。
 INVALIDPARAMETER_INVALIDURLREDIRECTHOST = 'InvalidParameter.InvalidUrlRedirectHost'
 
@@ -137,13 +242,22 @@ INVALIDPARAMETER_INVALIDURLREDIRECTURL = 'InvalidParameter.InvalidUrlRedirectUrl
 # 无效的WebSocket。
 INVALIDPARAMETER_INVALIDWEBSOCKETTIMEOUT = 'InvalidParameter.InvalidWebSocketTimeout'
 
+# 无效的缓存键。
+INVALIDPARAMETER_KEYRULESINVALIDQUERYSTRINGVALUE = 'InvalidParameter.KeyRulesInvalidQueryStringValue'
+
+# 参数长度超过限制。
+INVALIDPARAMETER_LENGTHEXCEEDSLIMIT = 'InvalidParameter.LengthExceedsLimit'
+
 # 参数错误。
 INVALIDPARAMETER_PARAMETERERROR = 'InvalidParameter.ParameterError'
 
+# 套餐不存在。
+INVALIDPARAMETER_PLANNOTFOUND = 'InvalidParameter.PlanNotFound'
+
 # 参数错误
 INVALIDPARAMETER_SECURITY = 'InvalidParameter.Security'
 
-# 参数错误-setting非法参数。
+# 配置项参数错误。
 INVALIDPARAMETER_SETTINGINVALIDPARAM = 'InvalidParameter.SettingInvalidParam'
 
 # 资源存在错误。
@@ -155,6 +269,9 @@ INVALIDPARAMETER_TASKNOTGENERATED = 'InvalidParameter.TaskNotGenerated'
 # 文件上传链接存在问题。
 INVALIDPARAMETER_UPLOADURL = 'InvalidParameter.UploadUrl'
 
+# 站点已被绑定。
+INVALIDPARAMETER_ZONEHASBEENBOUND = 'InvalidParameter.ZoneHasBeenBound'
+
 # 站点不存在。
 INVALIDPARAMETER_ZONENOTFOUND = 'InvalidParameter.ZoneNotFound'
 
@@ -179,6 +296,9 @@ INVALIDPARAMETERVALUE_INVALIDDNSCONTENT = 'InvalidParameterValue.InvalidDNSConte
 # DNS 记录名称错误。
 INVALIDPARAMETERVALUE_INVALIDDNSNAME = 'InvalidParameterValue.InvalidDNSName'
 
+# 加速域名状态不符合要求。
+INVALIDPARAMETERVALUE_INVALIDDOMAINSTATUS = 'InvalidParameterValue.InvalidDomainStatus'
+
 # DNS 代理域名错误。
 INVALIDPARAMETERVALUE_INVALIDPROXYNAME = 'InvalidParameterValue.InvalidProxyName'
 
@@ -200,6 +320,9 @@ LIMITEXCEEDED_BATCHQUOTA = 'LimitExceeded.BatchQuota'
 # 当天提交的资源数超过上限。
 LIMITEXCEEDED_DAILYQUOTA = 'LimitExceeded.DailyQuota'
 
+# 单位时间内接口请求频率达到限制。
+LIMITEXCEEDED_RATELIMITEXCEEDED = 'LimitExceeded.RateLimitExceeded'
+
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
@@ -212,9 +335,15 @@ OPERATIONDENIED_DOMAINNOICP = 'OperationDenied.DomainNoICP'
 # 4层代理资源处于封禁中，禁止操作。
 OPERATIONDENIED_L4PROXYINBANNEDSTATUS = 'OperationDenied.L4ProxyInBannedStatus'
 
+# 绑定4层实例有处于非运行中的状态，禁止操作。
+OPERATIONDENIED_L4STATUSNOTINONLINE = 'OperationDenied.L4StatusNotInOnline'
+
 # 已存在多个Cname接入站点，不允许切换至NS。
 OPERATIONDENIED_MULTIPLECNAMEZONE = 'OperationDenied.MultipleCnameZone'
 
+# NS接入模式不支持域名流量调度功能。
+OPERATIONDENIED_NSNOTALLOWTRAFFICSTRATEGY = 'OperationDenied.NSNotAllowTrafficStrategy'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -227,6 +356,12 @@ RESOURCEINUSE_CNAME = 'ResourceInUse.Cname'
 # Dns资源被占用。
 RESOURCEINUSE_DNS = 'ResourceInUse.Dns'
 
+# 已存在相同的别称域名。
+RESOURCEINUSE_DUPLICATENAME = 'ResourceInUse.DuplicateName'
+
+# 资源已被泛域名占用。
+RESOURCEINUSE_GENERICHOST = 'ResourceInUse.GenericHost'
+
 # 资源被本账号的子域名占用。
 RESOURCEINUSE_HOST = 'ResourceInUse.Host'
 
@@ -251,6 +386,9 @@ RESOURCEINUSE_OTHERSNS = 'ResourceInUse.OthersNS'
 # 资源被本账号和其他账号同时Cname接入占用。
 RESOURCEINUSE_SELFANDOTHERSCNAME = 'ResourceInUse.SelfAndOthersCname'
 
+# 别称域名已站点接入。
+RESOURCEINUSE_ZONE = 'ResourceInUse.Zone'
+
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
